package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenStaffInfo;
import org.apache.ibatis.annotations.Param;

/**
 * 厨房员工资料Mapper接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenStaffInfoMapper {
    /**
     * 查询厨房员工资料
     * 
     * @param staffId 厨房员工资料主键
     * @return 厨房员工资料
     */
    public KitchenStaffInfo selectKitchenStaffInfoByStaffId(Long staffId);

    /**
     * 查询厨房员工资料列表
     * 
     * @param kitchenStaffInfo 厨房员工资料
     * @return 厨房员工资料集合
     */
    public List<KitchenStaffInfo> selectKitchenStaffInfoList(KitchenStaffInfo kitchenStaffInfo);

    /**
     * 新增厨房员工资料
     * 
     * @param kitchenStaffInfo 厨房员工资料
     * @return 结果
     */
    public int insertKitchenStaffInfo(KitchenStaffInfo kitchenStaffInfo);

    /**
     * 修改厨房员工资料
     * 
     * @param kitchenStaffInfo 厨房员工资料
     * @return 结果
     */
    public int updateKitchenStaffInfo(KitchenStaffInfo kitchenStaffInfo);

    /**
     * 删除厨房员工资料
     * 
     * @param staffId 厨房员工资料主键
     * @return 结果
     */
    public int deleteKitchenStaffInfoByStaffId(Long staffId);

    /**
     * 批量删除厨房员工资料
     * 
     * @param staffIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenStaffInfoByStaffIds(Long[] staffIds);
}
